#
# spec file for package libkkc
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 2
Name:           libkkc
Version:        0.3.6~git20200818.e33e7fb
Release:        1.18
Summary:        Japanese Kana-string to Kana-Kanji-mixed-string converter
License:        GPL-3.0-only
Group:          System/I18n/Japanese
URL:            https://github.com/ueno/libkkc
Source:         %{name}-%{version}.tar.xz
Source1:        https://github.com/ueno/libkkc/releases/download/v0.3.5/libkkc-data-0.2.7.tar.xz
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM marguerite@opensuse.org - use correct shared library for typelib generation
Patch0:         libkkc-typelib-sharelib.patch
# PATCH-FIX-OPENSUSE marguerite@opensuse.org - lower gettext version
Patch1:         libkkc-gettext.patch
# PATCH-FIX-UPSTREAM marguerite@opensuse.org - public some classes to make vala 0.38 happy
Patch2:         libkkc-public.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
# for autogen.sh
BuildRequires:  gnome-common
BuildRequires:  gobject-introspection-devel
# json_generator_set_pretty is not available in version below.
BuildRequires:  json-glib-devel >= 0.14.0
BuildRequires:  libgee-devel >= 0.12.0
BuildRequires:  marisa-devel
BuildRequires:  pkg-config
BuildRequires:  vala >= 0.16.0
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libkkc provides a converter from Japanese Kana-string to Kana-Kanji-mixed-string.
It was named after kkc.el in GNU Emacs, a simple Kana Kanji converter,
while libkkc tries to convert sentences in a bit more complex way using N-gram
language models.

%package -n %{name}%{soname}
Summary:        Japanese Kana-string to Kana-Kanji-mixed-string convertion library
Group:          System/Libraries
Requires:       kkc-data
Requires:       skkdic
Requires:       skkdic-extra

%description -n %{name}%{soname}
libkkc provides a converter from Japanese Kana-string to Kana-Kanji-mixed-string.
It was named after kkc.el in GNU Emacs, a simple Kana Kanji converter,
while libkkc tries to convert sentences in a bit more complex way using N-gram
language models.

%package -n typelib-1_0-kkc-1_0
Summary:        Japanese Kana to Kana-Kanji converter -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-kkc-1_0
libkkc provides a converter from Japanese Kana-string to Kana-Kanji-mixed-string.

This package provides the GObject Introspection bindings for libkkc.

%package -n kkc-data
Summary:        Data files for %{name}
Group:          System/I18n/Japanese

%description -n kkc-data
libkkc provides a converter from Japanese Kana-string to Kana-Kanji-mixed-string.

This package provides the data files for libkkc.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soname} = %{version}

%description devel
libkkc provides a converter from Japanese Kana-string to Kana-Kanji-mixed-string.

This package contains its development headers and vala bindings.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
NOCONFIGURE=1 ./autogen.sh

%build
%configure --enable-introspection=yes \
	--enable-vala=yes \
	--enable-vapigen=yes
make %{?_smp_mflags}

# make data
cp -r %{SOURCE1} .
tar -xf %{name}-data-0.2.7.tar.xz
OLD=$(pwd)
pushd %{name}-data-0.2.7
cp -r ${OLD}/data/templates/libkkc-data/tools/genfilter.py tools/
cp -r ${OLD}/data/templates/libkkc-data/tools/sortlm.py tools/
%configure
# %{?_smp_mflags} cost too much memory
make
popd

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

find %{buildroot}%{_libdir} -name "*.la" -delete

# install data
pushd %{name}-data-0.2.7
make DESTDIR=%{buildroot} install %{?_smp_mflags}
popd

%fdupes %{buildroot}%{_datadir}/%{name}

%find_lang %{name}

%post -n %{name}%{soname} -p /sbin/ldconfig

%postun -n %{name}%{soname} -p /sbin/ldconfig

%files -n %{name}%{soname} -f %{name}.lang
%defattr(-,root,root)
%doc README COPYING
%{_bindir}/kkc
%{_libdir}/libkkc.so.%{soname}
%{_libdir}/libkkc.so.%{soname}.0.0
%{_datadir}/libkkc/

%files -n typelib-1_0-kkc-1_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/Kkc-1.0.typelib

%files -n kkc-data
%defattr(-,root,root)
%{_libdir}/%{name}/

%files devel
%defattr(-,root,root)
%{_bindir}/kkc-package-data
%{_includedir}/libkkc/
%{_libdir}/libkkc.so
%{_libdir}/pkgconfig/kkc-1.0.pc
%{_datadir}/gir-1.0/Kkc-1.0.gir
%{_datadir}/vala/vapi/kkc-1.0.deps
%{_datadir}/vala/vapi/kkc-1.0.vapi

%changelog
* Mon Sep 28 2020 i@marguerite.su
- Update to version 0.3.6~git20200818.e33e7fb:
  * travis: Enable SYS_PTRACE in Docker
  * build: Bump valadoc pkgconfig name
  * Update README.md
  * travis: Use python3 in coverage build
  * build: Bump valadoc pkgconfig name
  * build: Declare creation methods of abstract classes as protected
  * build: Enable python3
  * README.md: Link to the API references
  * travis: Deploy documentation
  * user-sentence-dictionary: Fix memleak
* Sat Oct 26 2019 fstrba@suse.com
- Update to version 0.3.5+git20190809.b2e5a15:
  * travis: Use python3 in coverage build
  * build: Bump valadoc pkgconfig name
  * build: Declare creation methods of abstract classes as protected
  * build: Enable python3
  * README.md: Link to the API references
  * travis: Deploy documentation
  * user-sentence-dictionary: Fix memleak
  * tests: Fix memleaks in tests
  * Fix memory leak caused by hacking strv length.
  * travis: Make coveralls work again under docker
  * Fix boo#1163932
* Wed Feb  7 2018 opensuse-packaging@opensuse.org
- Update to version 0.3.5+git20171220.7d365e1:
  * fix the modifier static is not applicable to constants
  * vala 0.32: use new operator to create new objects
  * Revert "vala 0.32: use new operator to create new objects"
  * build: Fix compile error with Vala 0.36
  * build: Migrate from intltool to gettext
  * build: Require valadoc-0.40
  * build: Use xz-compressed archive tarball
  * build: Set DIST_SUBDIRS for maintainer-clean target
  * Fix memory leak caused by hacking strv length.
- drop vala-0.23.2+-static-const.patch, upstreamed
- drop vala-0.32-new-operator.patch, upstreamed
- add libkkc-gettext.patch, lower gettext version for Leap
- add libkkc-public.patch, public some classes to make vala
  0.38 happy
* Tue Mar 28 2017 i@marguerite.su
- the previous new-op patch didn't pass upstream's travis test.
  vala upstream actually merged three warning messages into one.
  actually the build failed not due to a missing 'new' operator,
  but because of constructer chain-ups. use the official fix from
  libkkc upstream.
* Fri Mar 24 2017 i@marguerite.su
- add vala-0.23.2+-static-const.patch, fix 'the modifier static is
  not applicable to constants' warnings
- add vala-0.32-new-operator.patch, fix 'use new operator to create
  new objects' error
* Tue Aug 25 2015 i@marguerite.su
- Update to version 0.3.5+git20150522.650f0d6:
  + build: Make all-local depend on metadata.pot
  + build: Validate metadata.json against schema
  + gen-metadata-pot: Rewrite in Vala
  + Add ATOK style support.
  + rebased master and fixed some issues.
  + atok: Fix schema validation failure
  + rom-kana: Remove null entries in parent map
* Sun Sep  7 2014 ftake@geeko.jp
- update to version 0.3.4
  * assign "ly<X>" to HIRAGANA SMALL LETTER <X>
  * retain partial input when "convert-*" commands are called
  * update depending libraries
* Mon Jun  9 2014 i@marguerite.su
- update version 0.3.3
  * see git commit log for details
  * http://gitorious.org/libkkc/libkkc/commits/master
* Sat Oct 26 2013 i@marguerite.su
- update version 0.3.1 with data 0.2.7
  * see git commit log for details
  * http://gitorious.org/libkkc/libkkc/commits/master
- add requirements: skkdic skkdic-extra
  * kkc has the same author with skk, so he used his previous work
    as _default_ dictionary. No one knows that unless you use it.
* Fri Jul  5 2013 i@marguerite.su
- fix missing libkkc()(64bit) in typelib kkc.
* Tue Jun 25 2013 i@marguerite.su
- update version 0.2.4
  * see git commit log for details
  * http://gitorious.org/libkkc/libkkc/commits/master
* Thu Apr 25 2013 i@marguerite.su
- initial package 0.1.10
